@@ -69,7 +69,7 @@ def main(argv=None):
     logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
     conf = config.parse(args.config_file, args)
 
-    bibtex_database = bibparser.parse(*args.bibfile, detex=args.do_detex)
+    bibtex_database = bibparser.parse(*args.bibfile, do_detex=args.do_detex)
     if args.create_single_page:
         html = htmlexport.html_by_year(
             bibtex_database.entries,
