@@ -53,6 +53,7 @@ def _get_writer():
         "pdf",
         "postscript",
         "presentation",
-        "abstract" "keyword",
+        "abstract",
+        "keyword",
     )
     return writer
