@@ -46,12 +46,13 @@ class Config:
     def tail(self):
         return self._tail.format(timestamp=self._get_timestamp())
 
-    def _get_timestamp(self):
-        return datetime.now().strftime(r"%a %b %d %H:%M:%S %Y")
+    @staticmethod
+    def _get_timestamp():
+        return datetime.now().astimezone().strftime(r"%a %b %d %H:%M:%S %Y %Z")
 
 
 def parse(config_file: Optional[str], args) -> Config:
     if config_file is None:
         return Config({}, args)
-    with open(config_file) as inp:
+    with open(config_file, "rb") as inp:
         return Config(yaml.safe_load(inp), args)
