@@ -76,4 +76,7 @@ def get_download_link(doi: str) -> Optional[str]:
         link = f"https://link.springer.com/content/pdf/{doi}.pdf"
     if doi.startswith("10.1145/"):
         link = f"https://dl.acm.org/doi/pdf/{doi}"
+    if doi.startswith("10.48550/"):
+        arxive_id = doi.replace("10.48550/arXiv.", "")
+        link = f"https://arxiv.org/pdf/{arxive_id}"
     return link
